{% extends "base.html" %}

{% block head_title %}Login{% endblock %}

{% block body_content %}
    {% if form.errors %}
        <p class="error">Please correct the errors below:</p>
    {% endif %}
    
    <form method="POST" action="">
        <dl>
            <dt><label for="id_username">Username:</label>{% if form.username.errors %} <span class="error">{{ form.username.errors|join:", " }}</span>{% endif %}</dt>
            <dd>{{ form.username }}</dd>
            <dt><label for="id_password">Password:</label>{% if form.password.errors %} <span class="error">{{ form.password.errors|join:", " }}</span>{% endif %}</dt>
            <dd>{{ form.password }}</dd>
            <dt><input type="submit" value="Log in" /></dt>
        </dl>
    </form>
{% endblock %}