<html>
    <head>
        <title>{% block head_title %}{% endblock %}</title>
        <style>
            body {
                font-family: "Lucida Grande";
            }
            ul.errorlist {
                color: #F00;
                font-size: 80%;
                margin: 0;
                padding: 0;
                list-style: none;
            }
            .verified {
                color: green;
                font-size: 80%;
            }
            .unverified {
                color: gray;
                font-size: 80%;
            }
            .error {
                color: #F00;
                font-size: 80%;
            }
        </style>
    </head>
    <body>
        <h1>Email Confirmation Test</h1>
        
        {% block body_content %}
        {% endblock %}
    </body>
</html>