{% extends "base.html" %}

{% block head_title %}Signup{% endblock %}

{% block body_content %}
<form method="post" action="">
<table>{{ form.as_table }}</table>
<input type="submit" value="signup"/>
</form>
{% endblock %}