{% extends "base.html" %}

{% block head_title %}Confirm Email{% endblock %}

{% block body_content %}
{% if email_address %}
    <p>You have confirmed that {{ email_address.email }} is an email address for user '{{ email_address.user }}'.</p>
{% else %}
    <p>Invalid confirmation key.</p>
{% endif %}
<p>Go to <a href="/">homepage</a>.</p>
{% endblock %}